@@ -5,6 +5,7 @@ use std::any::Any;
 #[wiggle::async_trait]
 pub trait WasiFile: Send + Sync {
     fn as_any(&self) -> &dyn Any;
+    async fn sock_accept(&mut self, fdflags: FdFlags) -> Result<Box<dyn WasiFile>, Error>;
     async fn datasync(&self) -> Result<(), Error>; // write op
     async fn sync(&self) -> Result<(), Error>; // file op
     async fn get_filetype(&self) -> Result<FileType, Error>; // file op
@@ -34,6 +35,7 @@ pub trait WasiFile: Send + Sync {
     async fn seek(&self, pos: std::io::SeekFrom) -> Result<u64, Error>; // file op that generates a new stream from a file will supercede this
     async fn peek(&self, buf: &mut [u8]) -> Result<u64, Error>; // read op
     async fn num_ready_bytes(&self) -> Result<u64, Error>; // read op
+    fn isatty(&self) -> bool;
 
     async fn readable(&self) -> Result<(), Error>;
     async fn writable(&self) -> Result<(), Error>;
